@@ -218,7 +218,7 @@ class ShopifyBookService:
 
     def _create_metafield_definition(
         self, metafield_definition_input: CreateMetafieldDefinitionInput
-    ) -> MetafieldDefinition:
+    ) -> bool:
         """
         Creates a new metafield definition in the Shopify store.
 
@@ -235,7 +235,4 @@ class ShopifyBookService:
             operation_name="metafieldDefinitionCreate",
         )
         data = json.loads(result)
-        metafield_definition = to_metafield_definition(
-            data["data"]["metafieldDefinitionCreate"]["createdDefinition"]
-        )
-        return metafield_definition
+        return "errors" not in data
