@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 import abc
+import typing as t
 from decimal import Decimal
 from enum import Enum
 
@@ -35,10 +36,10 @@ class ShopifyBook(QuerySchema):
     title: str
     author: str
     price: Decimal
-    subtitle: str | None
-    description: str | None
-    publisher: str | None
-    published_date: str | None
+    subtitle: t.Optional[str]
+    description: t.Optional[str]
+    publisher: t.Optional[str]
+    published_date: t.Optional[str]
 
     @property
     def id(self) -> int:
@@ -56,12 +57,12 @@ class CreateBookInput(MutationSchema):
     author: str
     price: Decimal
     product_type: str = "Textbook"
-    subtitle: str | None = None
-    description: str | None = None
-    publisher: str | None = None
-    published_date: str | None = None
-    cover_image: str | None = None
-    staff_comment: str | None = None
+    subtitle: t.Optional[str] = None
+    description: t.Optional[str] = None
+    publisher: t.Optional[str] = None
+    published_date: t.Optional[str] = None
+    cover_image: t.Optional[str] = None
+    staff_comment: t.Optional[str] = None
     tags: list[str] = []
 
     @validator("isbn")
@@ -117,13 +118,13 @@ class CreateBookInput(MutationSchema):
 
 class UpdateBookInput(MutationSchema):
     product_id: int
-    isbn: str | None = None
-    title: str | None = None
-    author: str | None = None
-    subtitle: str | None = None
-    description: str | None = None
-    publisher: str | None = None
-    published_date: str | None = None
+    isbn: t.Optional[str] = None
+    title: t.Optional[str] = None
+    author: t.Optional[str] = None
+    subtitle: t.Optional[str] = None
+    description: t.Optional[str] = None
+    publisher: t.Optional[str] = None
+    published_date: t.Optional[str] = None
 
     @validator("isbn")
     def isbn_must_be_10_or_13_digits(cls, v):
@@ -135,15 +136,10 @@ class UpdateBookInput(MutationSchema):
 
 
 class MetafieldDefinition(QuerySchema):
-    gid: str
     key: str
     name: str
     namespace: str
-    description: str | None
-
-    @property
-    def id(self) -> int:
-        return int(self.gid.split("/")[-1])
+    description: t.Optional[str]
 
 
 class MetafieldType(str, Enum):
